@@ -28,7 +28,7 @@ Moose::Exporter->setup_import_methods(
     as_is => [qw/get_options/],
 );
 
-our $VERSION = version->new('0.3.1');
+our $VERSION = version->new('0.3.2');
 our $EXIT    = 1;
 
 has options => (
@@ -142,23 +142,37 @@ around BUILDARGS => sub {
     }
 
     if ( @params ) {
-        # construct a class of options passing
-        my $class_name = 'Getopt::Alt::Dynamic::A' . $count++;
-        my $option_class = Moose::Meta::Class->create(
-            $class_name,
-            superclasses => [ $param{options} || 'Getopt::Alt::Dynamic' ],
-        );
+        $param{options} = _build_option_class($param{options} || 'Getopt::Alt::Dynamic', @params);
 
-        while ( my $option = shift @params ) {
-            build_option($option_class, $option);
+        if (0 && $param{sub_command} && ref $param{sub_command} eq 'HASH') {
+
+            # build up all the sub command options
+            for my $sub (keys %{ $param{sub_command} }) {
+                $param{sub_command}{$sub} = _build_option_class($param{options}, $param{sub_command}{$sub});
+            }
         }
-
-        $param{options} = $class_name;
     }
 
     return $class->$orig(%param);
 };
 
+sub _build_option_class {
+    my ($base_class, @params) = @_;
+
+    # construct a class of options passing
+    my $class_name = 'Getopt::Alt::Dynamic::A' . $count++;
+    my $option_class = Moose::Meta::Class->create(
+        $class_name,
+        superclasses => [ $base_class ],
+    );
+
+    while ( my $option = shift @params ) {
+        build_option($option_class, $option);
+    }
+
+    return $class_name;
+}
+
 sub BUILD {
     my ($self) = @_;
 
@@ -170,9 +184,9 @@ sub BUILD {
     });
 
     $conf = {
-        map { $_ ? %$_ : () }
+        map { %$_ }
         map { values %$_    }
-        @{ $conf || [] }
+        @{ $conf }
     };
 
     # perlcritic is confused here combining hashes is not the same as comma separated arguments
@@ -187,7 +201,7 @@ sub BUILD {
     return;
 }
 
-sub get_options {  ## no critic
+sub get_options {
     my @args = @_;
     my $caller = caller;
 
@@ -306,15 +320,16 @@ sub process {
     }
 
     if ( ref $self->sub_command eq 'HASH' ) {
-        my $sub = [ @{$self->sub_command->{$self->cmd}} ];
-        if (!$sub) {
+        if (!$self->sub_command->{$self->cmd}) {
             warn "Unknown command '$self->cmd'!\n";
             die Getopt::Alt::Exception->new( message => "Unknown command '$self->cmd'" )
                 if !$self->help_package;
             $self->_show_help(1);
         }
 
-        if ( ref $sub eq 'ARRAY' ) {
+        if ( ref $self->sub_command->{$self->cmd} eq 'ARRAY' ) {
+            # make a copy of the sub command
+            my $sub = [ @{$self->sub_command->{$self->cmd}} ];
             # check the style
             my $options  = @$sub == 2 && ref $sub->[0] eq 'HASH' && ref $sub->[1] eq 'ARRAY' ? shift @$sub : {};
             my $opt_args = %$options ? $sub->[0] : $sub;
@@ -468,7 +483,7 @@ Getopt::Alt - Command line option passing with with lots of features
 
 =head1 VERSION
 
-This documentation refers to Getopt::Alt version 0.3.1.
+This documentation refers to Getopt::Alt version 0.3.2.
 
 =head1 SYNOPSIS
 
