@@ -19,8 +19,7 @@ Moose::Exporter->setup_import_methods(
     #with_meta => ['operation'],
 );
 
-
-our $VERSION = version->new('0.3.1');
+our $VERSION = version->new('0.3.2');
 
 Moose::Util::meta_attribute_alias('Getopt::Alt::Option');
 
@@ -204,21 +203,27 @@ sub process {
     if ($self->type) {
         $used = 1;
         if ( !defined $arg_data || length $arg_data == 0 ) {
-            die [ Getopt::Alt::Exception->new(
-                    message => "The option '$name' requires an " . $self->type . " argument\n",
-                    option  => $name,
-                    type    => $self->type
-                ) ]
-                if ( ! defined $args->[0]  && !$self->nullable ) || (
-                    $args->[0] && $args->[0] =~ /^-/xms && !( $self->type eq 'Int' || $self->type eq 'Num' )
-                );
+            if (
+                ( ! defined $args->[0]  && !$self->nullable )
+                || (
+                    $args->[0]
+                    && $args->[0] =~ /^-/xms
+                    && !( $self->type eq 'Int' || $self->type eq 'Num' )
+                )
+            ) {
+                die [
+                    Getopt::Alt::Exception->new(
+                        message => "The option '$name' requires an " . $self->type . " argument\n",
+                        option  => $name,
+                        type    => $self->type
+                    )
+                ];
+            }
 
             $arg_data = shift @$args;
         }
-        elsif ( $self->ref || grep { $self->type eq $_ } qw/Int Num Str/ ) {
-            if ( $arg_data && !$self->nullable ) {
-                $arg_data =~ s/^=//xms;
-            }
+        elsif ( $arg_data && !$self->nullable ) {
+            $arg_data =~ s/^=//xms;
         }
 
         my $key;
@@ -226,12 +231,13 @@ sub process {
             ($key, $arg_data) = split /=/xms, $arg_data, 2;
         }
 
+        $DB::single = 1;
         $value =
-              $self->nullable      && ( !defined $arg_data || $arg_data eq '' )             ? undef
+              $self->nullable      &&   !        $arg_data                                  ? undef
             : $self->type eq 'Int' && $arg_data =~ /^ -? \d+$/xms                           ? $arg_data
             : $self->type eq 'Num' && $arg_data =~ /^ -? (?: \d* (?: [.]\d+ )? | \d+ )$/xms ? $arg_data
-            : $self->type eq 'Str' && length $arg_data > 0                                  ? $arg_data
-            :                                                                                 confess "The value '$arg_data' is not of type '".$self->type."'\n";
+            : $self->type eq 'Str'                                                          ? $arg_data
+            :                                                                                 confess "Unknown type '".$self->type."'\n";
 
         if ($self->values && !grep { $value eq $_ } @{ $self->values }) {
             die [ Getopt::Alt::Exception->new(
@@ -257,9 +263,6 @@ sub process {
     elsif ($self->increment) {
         $value = ($self->value || 0) + 1;
     }
-    elsif ($self->number) {
-        $value = $long || $short
-    }
     elsif ($self->negatable) {
         $value = $long && $long =~ /^no-/xms ? 0 : 1;
     }
@@ -282,7 +285,7 @@ Getopt::Alt::Option - Sets up a particular command line option
 
 =head1 VERSION
 
-This documentation refers to Getopt::Alt::Option version 0.3.1.
+This documentation refers to Getopt::Alt::Option version 0.3.2.
 
 =head1 SYNOPSIS
 
